/*
 * FCRON - periodic command scheduler 
 *
 *  Copyright 2000 Thibault Godouet <fcron@free.fr>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 * 
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 *  The GNU General Public License can also be found in the file
 *  `LICENSE' that comes with the fcron source distribution.
 */

 /* $Id: config.h,v 1.14 2000/08/29 18:01:39 thib Exp $ */


/* *********************************************************** */
/* This file is destined to be edited to match your preference */
/* *********************************************************** */


/* ****************************************************************** */
/* beginning of configurable stuff ********************************** */


/* *** options which can be set in Makefile *** */
/* (they are overridden by Makefile's value ) */

#ifndef VERSION
#define VERSION	"1.0.0"   /* default version if not defined in Makefile */
#endif

#ifndef FCRONTABS        /* directory where is stored users' fcrontabs */
#define FCRONTABS	"/var/spool/fcron/"
#endif

#ifndef ETC             /* directory where are stored fcrontab.allow/deny */
#define ETC             "/etc/"
#endif

#ifndef PROC            /* directory where is mounted the procfs */
#define PROC            "/proc/"
#endif

#ifndef DEBUG
#define DEBUG           0  /* 1 if you want debug mode */
#endif

#ifndef FOREGROUND
#define FOREGROUND      0  /* 1 if you want foreground mode by default */
#endif

#ifndef SAVE
#define SAVE            1800  /* save every n seconds */
#endif



/* *** system dependent *** */
#define EXIT_ERR   1         /* code returned by fcron/fcrontab on error */
#define EXIT_OK    0         /* code returned  on normal exit */


/* *** paths *** */

/* fcron allow and deny file are located in directory ETC (see below) */
#define FCRON_ALLOW      "fcron.allow"

#define FCRON_DENY       "fcron.deny"

#define SENDMAIL	"/usr/lib/sendmail" /* mail command */

#define SENDMAIL_ARGS	"-Ffcron", "-odi"   /* args of mail command */

#define EDITOR          "/usr/bin/vi"       /* default editor */

#define SHELL           "/bin/sh"           /* default shell */

#define PIDFILE		"/var/run/fcron.pid" /* where is located pid file ? */


/* *** memory *** */
#define EXE_INITIAL_SIZE 6 /* initial number of possible running job 
			    * if more jobs have to be run simultaneously,
			    * fcron will have to calloc() more memory */
#define EXE_GROW_SIZE 5 /* this is the number of entries that will be
			 * added to exe_array each time it has to grow
			 * up */

#define SERIAL_QUEUE_MAX 30 /* if serial queue contains this number of entries,
			     * the next serial job to be executed will be run
			     * non-serially each time a serial job is added */
#define SERIAL_INITIAL_SIZE 10 /* initial number of possible serial job. If
				* more jobs have to be in queue simultaneously,
				* fcron will have to calloc() more memory */
#define SERIAL_GROW_SIZE 10 /* this is the number of entries that will be
			     * added to serial queue each time it has to grow
			     * up */

#define LAVG_QUEUE_MAX 30 /* if lavg queue contains this number of entries,
			   * the next lavg job to be executed will be run
			   * before a new lavg job is added */
#define LAVG_INITIAL_SIZE 10 /* initial number of possible lavg job. If
			      * more jobs have to be in queue simultaneously,
			      * fcron will have to calloc() more memory */
#define LAVG_GROW_SIZE 10 /* this is the number of entries that will be
			   * added to lavg queue each time it has to grow
			   * up */


#define MAXENTRIES  256  /* max lines in non-root fcrontabs */

#define LINE_LEN    1024     /* max line length in user's config file */
#define FNAME_LEN 512        /* max length of a file name */
#define USER_NAME_LEN 128    /* max length of a user name */
#define PATH_LEN 256         /* max length of a file path */

#define MAX_MSG 150           /* max length of a log message */


/* *** time *** */
#define FIRST_SLEEP 20      /* fcron sleep at least this time after startup
			     * before executing a job, to avoid to run jobs
			     * during system boot */

#define LAVG_SLEEP 30 /* the time we sleep when some jobs are in lavg queue */


/* *** behavior *** */
#define SERIAL_ONCE 0 /* can a job be several times in the serial queue at
		       * the same moment ? */

#define LAVG_ONCE 1 /* can a job be several times in the lavg queue at
		     * the same moment ? */

/* Syslog facility and priorities messages will be logged to (see syslog(3)) */

/* NOTE : if you change anything here, check if the doc should not
          be updated
*/
#define SYSLOG_FACILITY LOG_CRON
#define EXPLAIN_LEVEL LOG_NOTICE  /* informational messages */
#define WARNING_LEVEL LOG_WARNING /* warning messages */
#define COMPLAIN_LEVEL LOG_ERR    /* error messages */
#define DEBUG_LEVEL LOG_DEBUG     /* only used when DEBUG is defined */



/* end of configurable stuff **************************************** */
/* ****************************************************************** */

